# Doctor Quote's "Mighty Maxims" Effort

Welcome to the official 'pythonic quote-share for Doctor Quote.

## MightyMaxims: The Module

The quotes in this package are from the 2021 paperback. Available on the 'Zon.

After installing simply:

```
>>> import MightyMaxims
>>> help(MightyMaxims)
```

(Yea - I know - but printing quotes is what this 'pup is designed to do. Think `antigravity`? ;-)


